===============================
dbaas-foxha
===============================



.. image:: https://pyup.io/repos/github/otherpirate/cookiecutter-django/shield.svg
     :target: https://pyup.io/repos/github/otherpirate/dbaas-foxha/
     :alt: Updates


DBaaS FoxHA is a simple FoxHA api wrapper for DBaaS



Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

